#!/bin/bash

LOGFILE="/var/log/alt-php-cleanup-sessions.log"

USERS=$(cagefsctl --list-enabled | tail -n +2 | grep -v '^[[:space:]]*$')

echo "=============================================" >> $LOGFILE
echo "Starting alt-php-cleanup-sessions.sh ($(date))" >> $LOGFILE

if pidof -x $(basename $0) -o %PPID > /dev/null
then
    echo "Script already running, aboring." >> $LOGFILE
    exit 1
fi

echo "cagefs users:" >> $LOGFILE
echo "$USERS" >> $LOGFILE

while IFS= read -r user; do
    echo "----" >> $LOGFILE
    echo "Processing user: $user" >> $LOGFILE
    SESS_LIFETIME=$(cagefs_enter_user $user php -r "echo ini_get('session.gc_maxlifetime');")
    SESS_LOCATION=$(cagefs_enter_user $user php -r "echo session_save_path();")
    if [[ -z "$SESS_LOCATION" ]]; then
      echo "Empty session location, skipping user" >> $LOGFILE
      continue
    fi
    if ! [[ $SESS_LIFETIME =~ ^[0-9]+$ ]]; then
      echo "Invalid session lifetime: $SESS_LIFETIME" >> $LOGFILE
      continue
    fi
    if (( $SESS_LIFETIME <= 0 )); then
      echo "Non-positive session lifetime: $SESS_LIFETIME" >> $LOGFILE
      continue
    fi
    echo "Session duration for $user: $SESS_LIFETIME ($SESS_LOCATION), cleaning up..." >> $LOGFILE
    pushd /tmp >/dev/null # we need to suppress 'Failed to restore initial working directory' warning
    CLEANED_LIST=$(cagefs_enter_user $user find $SESS_LOCATION -type f -not -newermt "$SESS_LIFETIME seconds ago" -delete -print)
    if [[ "$CLEANED_LIST" == "" ]]; then
      echo "No sessions to clean." >> $LOGFILE
    else
      echo "Cleaned $(echo $CLEANED_LIST | wc -l) session(s)." >> $LOGFILE
    fi
    popd >/dev/null
done <<< "$USERS"
